@@ -1,6 +1,6 @@
 /* ide-debugger.h
  *
- * Copyright (C) 2017 Christian Hergert <chergert@redhat.com>
+ * Copyright © 2017 Christian Hergert <chergert@redhat.com>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,6 +20,8 @@
 
 #include <gio/gio.h>
 
+#include "ide-version-macros.h"
+
 #include "ide-object.h"
 
 #include "debugger/ide-debugger-breakpoint.h"
@@ -184,6 +186,7 @@ struct _IdeDebuggerClass
                                           GAsyncResult                   *result,
                                           GError                        **error);
 
+  /*< private >*/
   gpointer _reserved1;
   gpointer _reserved2;
   gpointer _reserved3;
@@ -218,149 +221,199 @@ struct _IdeDebuggerClass
   gpointer _reserved32;
 };
 
+IDE_AVAILABLE_IN_ALL
 gboolean           ide_debugger_supports_runner           (IdeDebugger                    *self,
                                                            IdeRunner                      *runner,
                                                            gint                           *priority);
+IDE_AVAILABLE_IN_ALL
 void               ide_debugger_prepare                   (IdeDebugger                    *self,
                                                            IdeRunner                      *runner);
+IDE_AVAILABLE_IN_ALL
 GListModel        *ide_debugger_get_breakpoints           (IdeDebugger                    *self);
+IDE_AVAILABLE_IN_ALL
 const gchar       *ide_debugger_get_display_name          (IdeDebugger                    *self);
+IDE_AVAILABLE_IN_ALL
 void               ide_debugger_set_display_name          (IdeDebugger                    *self,
                                                            const gchar                    *display_name);
+IDE_AVAILABLE_IN_ALL
 gboolean           ide_debugger_get_is_running            (IdeDebugger                    *self);
+IDE_AVAILABLE_IN_ALL
 gboolean           ide_debugger_get_can_move              (IdeDebugger                    *self,
                                                            IdeDebuggerMovement             movement);
+IDE_AVAILABLE_IN_ALL
 GListModel        *ide_debugger_get_threads               (IdeDebugger                    *self);
+IDE_AVAILABLE_IN_ALL
 GListModel        *ide_debugger_get_thread_groups         (IdeDebugger                    *self);
+IDE_AVAILABLE_IN_ALL
 IdeDebuggerThread *ide_debugger_get_selected_thread       (IdeDebugger                    *self);
+IDE_AVAILABLE_IN_ALL
 void               ide_debugger_disassemble_async         (IdeDebugger                    *self,
                                                            const IdeDebuggerAddressRange  *range,
                                                            GCancellable                   *cancellable,
                                                            GAsyncReadyCallback             callback,
                                                            gpointer                        user_data);
+IDE_AVAILABLE_IN_ALL
 GPtrArray         *ide_debugger_disassemble_finish        (IdeDebugger                    *self,
                                                            GAsyncResult                   *result,
                                                            GError                        **error);
+IDE_AVAILABLE_IN_ALL
 void               ide_debugger_insert_breakpoint_async   (IdeDebugger                    *self,
                                                            IdeDebuggerBreakpoint          *breakpoint,
                                                            GCancellable                   *cancellable,
                                                            GAsyncReadyCallback             callback,
                                                            gpointer                        user_data);
+IDE_AVAILABLE_IN_ALL
 gboolean           ide_debugger_insert_breakpoint_finish  (IdeDebugger                    *self,
                                                            GAsyncResult                   *result,
                                                            GError                        **error);
+IDE_AVAILABLE_IN_ALL
 void               ide_debugger_interrupt_async           (IdeDebugger                    *self,
                                                            IdeDebuggerThreadGroup         *thread_group,
                                                            GCancellable                   *cancellable,
                                                            GAsyncReadyCallback             callback,
                                                            gpointer                        user_data);
+IDE_AVAILABLE_IN_ALL
 gboolean           ide_debugger_interrupt_finish          (IdeDebugger                    *self,
                                                            GAsyncResult                   *result,
                                                            GError                        **error);
+IDE_AVAILABLE_IN_ALL
 void               ide_debugger_modify_breakpoint_async   (IdeDebugger                    *self,
                                                            IdeDebuggerBreakpointChange     change,
                                                            IdeDebuggerBreakpoint          *breakpoint,
                                                            GCancellable                   *cancellable,
                                                            GAsyncReadyCallback             callback,
                                                            gpointer                        user_data);
+IDE_AVAILABLE_IN_ALL
 gboolean           ide_debugger_modify_breakpoint_finish  (IdeDebugger                    *self,
                                                            GAsyncResult                   *result,
                                                            GError                        **error);
+IDE_AVAILABLE_IN_ALL
 void               ide_debugger_remove_breakpoint_async   (IdeDebugger                    *self,
                                                            IdeDebuggerBreakpoint          *breakpoint,
                                                            GCancellable                   *cancellable,
                                                            GAsyncReadyCallback             callback,
                                                            gpointer                        user_data);
+IDE_AVAILABLE_IN_ALL
 gboolean           ide_debugger_remove_breakpoint_finish  (IdeDebugger                    *self,
                                                            GAsyncResult                   *result,
                                                            GError                        **error);
+IDE_AVAILABLE_IN_ALL
 void               ide_debugger_list_breakpoints_async    (IdeDebugger                    *self,
                                                            GCancellable                   *cancellable,
                                                            GAsyncReadyCallback             callback,
                                                            gpointer                        user_data);
+IDE_AVAILABLE_IN_ALL
 GPtrArray         *ide_debugger_list_breakpoints_finish   (IdeDebugger                    *self,
                                                            GAsyncResult                   *result,
                                                            GError                        **error);
+IDE_AVAILABLE_IN_ALL
 void               ide_debugger_list_frames_async         (IdeDebugger                    *self,
                                                            IdeDebuggerThread              *thread,
                                                            GCancellable                   *cancellable,
                                                            GAsyncReadyCallback             callback,
                                                            gpointer                        user_data);
+IDE_AVAILABLE_IN_ALL
 GPtrArray         *ide_debugger_list_frames_finish        (IdeDebugger                    *self,
                                                            GAsyncResult                   *result,
                                                            GError                        **error);
+IDE_AVAILABLE_IN_ALL
 void               ide_debugger_list_locals_async         (IdeDebugger                    *self,
                                                            IdeDebuggerThread              *thread,
                                                            IdeDebuggerFrame               *frame,
                                                            GCancellable                   *cancellable,
                                                            GAsyncReadyCallback             callback,
                                                            gpointer                        user_data);
+IDE_AVAILABLE_IN_ALL
 GPtrArray         *ide_debugger_list_locals_finish        (IdeDebugger                    *self,
                                                            GAsyncResult                   *result,
                                                            GError                        **error);
+IDE_AVAILABLE_IN_ALL
 void               ide_debugger_list_params_async         (IdeDebugger                    *self,
                                                            IdeDebuggerThread              *thread,
                                                            IdeDebuggerFrame               *frame,
                                                            GCancellable                   *cancellable,
                                                            GAsyncReadyCallback             callback,
                                                            gpointer                        user_data);
+IDE_AVAILABLE_IN_ALL
 GPtrArray         *ide_debugger_list_params_finish        (IdeDebugger                    *self,
                                                            GAsyncResult                   *result,
                                                            GError                        **error);
+IDE_AVAILABLE_IN_ALL
 void               ide_debugger_list_registers_async      (IdeDebugger                    *self,
                                                            GCancellable                   *cancellable,
                                                            GAsyncReadyCallback             callback,
                                                            gpointer                        user_data);
+IDE_AVAILABLE_IN_ALL
 GPtrArray         *ide_debugger_list_registers_finish     (IdeDebugger                    *self,
                                                            GAsyncResult                   *result,
                                                            GError                        **error);
+IDE_AVAILABLE_IN_ALL
 void               ide_debugger_move_async                (IdeDebugger                    *self,
                                                            IdeDebuggerMovement             movement,
                                                            GCancellable                   *cancellable,
                                                            GAsyncReadyCallback             callback,
                                                            gpointer                        user_data);
+IDE_AVAILABLE_IN_ALL
 gboolean           ide_debugger_move_finish               (IdeDebugger                    *self,
                                                            GAsyncResult                   *result,
                                                            GError                        **error);
+IDE_AVAILABLE_IN_ALL
 void               ide_debugger_send_signal_async         (IdeDebugger                    *self,
                                                            gint                            signum,
                                                            GCancellable                   *cancellable,
                                                            GAsyncReadyCallback             callback,
                                                            gpointer                        user_data);
+IDE_AVAILABLE_IN_ALL
 gboolean           ide_debugger_send_signal_finish        (IdeDebugger                    *self,
                                                            GAsyncResult                   *result,
                                                            GError                        **error);
+IDE_AVAILABLE_IN_ALL
 const gchar       *ide_debugger_locate_binary_at_address  (IdeDebugger                    *self,
                                                            IdeDebuggerAddress              address);
+IDE_AVAILABLE_IN_ALL
 void               ide_debugger_emit_log                  (IdeDebugger                    *self,
                                                            IdeDebuggerStream               stream,
                                                            GBytes                         *content);
+IDE_AVAILABLE_IN_ALL
 void               ide_debugger_emit_thread_group_added   (IdeDebugger                    *self,
                                                            IdeDebuggerThreadGroup         *thread_group);
+IDE_AVAILABLE_IN_ALL
 void               ide_debugger_emit_thread_group_removed (IdeDebugger                    *self,
                                                            IdeDebuggerThreadGroup         *thread_group);
+IDE_AVAILABLE_IN_ALL
 void               ide_debugger_emit_thread_group_started (IdeDebugger                    *self,
                                                            IdeDebuggerThreadGroup         *thread_group);
+IDE_AVAILABLE_IN_ALL
 void               ide_debugger_emit_thread_group_exited  (IdeDebugger                    *self,
                                                            IdeDebuggerThreadGroup         *thread_group);
+IDE_AVAILABLE_IN_ALL
 void               ide_debugger_emit_thread_added         (IdeDebugger                    *self,
                                                            IdeDebuggerThread              *thread);
+IDE_AVAILABLE_IN_ALL
 void               ide_debugger_emit_thread_removed       (IdeDebugger                    *self,
                                                            IdeDebuggerThread              *thread);
+IDE_AVAILABLE_IN_ALL
 void               ide_debugger_emit_thread_selected      (IdeDebugger                    *self,
                                                            IdeDebuggerThread              *thread);
+IDE_AVAILABLE_IN_ALL
 void               ide_debugger_emit_breakpoint_added     (IdeDebugger                    *self,
                                                            IdeDebuggerBreakpoint          *breakpoint);
+IDE_AVAILABLE_IN_ALL
 void               ide_debugger_emit_breakpoint_modified  (IdeDebugger                    *self,
                                                            IdeDebuggerBreakpoint          *breakpoint);
+IDE_AVAILABLE_IN_ALL
 void               ide_debugger_emit_breakpoint_removed   (IdeDebugger                    *self,
                                                            IdeDebuggerBreakpoint          *breakpoint);
+IDE_AVAILABLE_IN_ALL
 void               ide_debugger_emit_running              (IdeDebugger                    *self);
+IDE_AVAILABLE_IN_ALL
 void               ide_debugger_emit_stopped              (IdeDebugger                    *self,
                                                            IdeDebuggerStopReason           stop_reason,
                                                            IdeDebuggerBreakpoint          *breakpoint);
+IDE_AVAILABLE_IN_ALL
 void               ide_debugger_emit_library_loaded       (IdeDebugger                    *self,
                                                            IdeDebuggerLibrary             *library);
+IDE_AVAILABLE_IN_ALL
 void               ide_debugger_emit_library_unloaded     (IdeDebugger                    *self,
                                                            IdeDebuggerLibrary             *library);
 
